/***************************************************/
/* Pipe.x  Criteria for SCDOT Drainage             */
/*                                                 */
/* Written By: Derricke Gray - Bentley Civil       */
/* Date: December, 2007                            */
/*                                                 */
/* Modified By: Dave Hoerner - Bentley             */
/* Date: July 2nd, 2008                            */
/*                                                 */
/***************************************************/

sub pipe
{
   /* INCLUDE SYMBOLOGY DEFINITIONS FROM SEPARATE CRITERIA FILE */
   include LevelSymbology.x
    
   /* SET SCALE RATIO USING INTRINSIC VARIABLE */  
   _d_Ratio = HORIZONTAL TO VERTICAL SCALE RATIO

   set plot parameters "Pipe Symbology"

   /* MARK POINTS AT BOTH LEFT AND RIGHT, TOP AND BOTTOM OF CROSSING PIPE */
   draw skip to drainage link begin point		mark x1 y1
   draw skip dx=0 dy=Drainage Link Rise  		mark x2 y2
   draw skip to drainage link end point			mark x3 y3
   draw skip dx=0 dy=Drainage Link Rise 		mark x4 y4
   
   /* DRAW TOP OF CROSSING PIPE */
   draw to x2 y2
   
   /* MOVE TO THE BOTTOM STARTING POINT */
   draw skip to x1 y1
   
   /* DRAW BOTTOM OF CROSSING PIPE */
   draw to x3 y3   

   /* PIPE ID */
   _s_PipeId = Drainage Link ID

   /* CALCULATE PIPE SIZE */
   _d_PipeSize = Drainage Link Rise * 12
   _s_PipeSize = cvt_d_s0(_d_PipeSize) + ^" PIPE ^ + _s_PipeId 
            
   /* CALCULATE PIPE LENGTH */
   _d_PipeLength = Drainage Link Actual Length
   _s_PipeLength = cvt_d_s2(_d_PipeLength) + ^'^
   
   /* CALCULATE PIPE SLOPE */
   _d_PipeSlope = (abs(y1 - y3)/abs(x1 - x3)) * 100
   _s_PipeSlope = cvt_d_s2(_d_PipeSlope) + ^%^
   
   /* BUILD COMPLETE PIPE LABEL */
   _s_PipeLabel = ^ (^ + Drainage Link ID + ^) ^ + _s_PipeLength + ^ - ^ + Drainage Link Library Item + ^ @ ^ + _s_PipeSlope
   /* _s_PipeLabel = ^ (^ + Drainage Link ID + ^) ^ + ^= ^ _s_PipeLength + ^ - ^ + Drainage Link Library Item + ^ (^ + Drainage Link ID +^) ^ + ^ @ ^ + _s_PipeSlope */
   
   /* MOVE TO THE CENTER OF THE CROSSING PIPE */
   draw skip to x1 y1
   draw skip dx=-1 * (x1 - x3)/2 dy=(y3 - y1)/2	
   draw skip dx=0 dy=(Drainage Link Rise/2)                  mark x50 y50
   
   /* PLACE PIPE LABEL */
   if x1 < x3 then
     {
       draw text value= _s_PipeLabel "Pipe Text Symbology" just=CC angle=line between x1 y1 and x3 y3
     }
   else if x3 < x1 then
     {
       draw text value=_s_PipeLabel "Pipe Text Symbology" just=CC angle=line between x3 y3 and x1 y1
     }
   
   /* PIPE FLOWS RIGHT TO LEFT */
   if ((x3 > x1) AND (y3 > y1)) OR
      ((x1 > x3) AND (y1 > y3)) then
     {
       set plot parameters "Delimiter Line Symbology"
       draw skip dx=-10 dy=(-_d_PipeSlope/10)               mark x60 y60
       draw slope = (-_d_PipeSlope) for dx=-2.5             mark x61 y61    
       draw dx=.75 dy=.3
       draw skip to x61 y61
       draw dx=.75 dy=-.3
       draw skip to x50 y50
       draw skip dx=10 dy=(_d_PipeSlope/10)                 mark x61 y61
       draw slope = (_d_PipeSlope) for dx=2.5                   
       draw skip to x61 y61
       draw dx=.75 dy=.3
       draw skip to x61 y61
       draw dx=.75 dy=-.3
     }
  /* PIPE FLOWS LEFT TO RIGHT */
  else if ((x3 > x1) AND (y3 < y1)) OR
          ((x1 > x3) AND (y1 < y3)) then
     {
       set plot parameters "Delimiter Line Symbology"
       draw skip dx=-10 dy=(_d_PipeSlope/10)                mark x61 y61
       draw slope = (_d_PipeSlope) for dx=-2.5              mark x60 y60
       draw skip to x61 y61                                    
       draw dx=-.75 dy=.3
       draw skip to x61 y61
       draw dx=-.75 dy=-.3
       draw skip to x50 y50
       draw skip dx=10 dy=(-_d_PipeSlope/10)                 mark x60 y60                
       draw slope = (-_d_PipeSlope) for dx=2.5               mark x61 y61
       draw dx=-.75 dy=.3
       draw skip to x61 y61
       draw dx=-.75 dy=-.3     
     }
} 
end subroutine