/*    Critical Point Calculation for Widening/Relocation.    */
/* ------------------------------------------------------------
    This program will 
		-  Locate Critical Points.
            -  Calculate C/L Elevation and 'minimum overlay depth'.
            -  Redraw Pavement Templates (shifting up or down). 
		-  Mark 'CL' and elevation at the Base Line location for Profile Design. 
		-  Mark 'CP' at the Min. Distance (Critical Point).


      for Widening/Relocation projects (proposed pavement
      is wider than existing pavement). 

	Required:  
		-  x-section (dx) file with existing ground.	
		-  existing edge of travel lane on plan view (pp.dgn).  
		-  SE shapes tie to the existing. 
            -  Minimum overlay depth.					

draw skip trace in off=0 for dx=300                 		NPY  09/28/01  
set plot param lv = 50 co = 14 wt = 1 lc = 0	 		NPY  03/12/04	
Change to level names							NPY  4/25/06	

Include definitions: in std_vars.x:					NPY  4/25/06
		"~critical point CL text symbology" 
		"~critical surface symbology"
		"~slope text symbology" 
		"~warning text symbology"
		"~XS notes line symbology"
		"~XS notes text symbology"
		"~existing EOP text symbology" 

---------------------------------------------------------------------------  */

define "minimum overlay depth" 0.3

define_dgn "exground" \
       dgn = ****.dgn \
       lvname=RD_XS_ExGround
        
define_dgn "existing edge of travel lane" \
	dgn = ****.dgn \
	lvname=RD_EX_Road

if p2 then
 {
   /* --------------------------------------------------------------------- */
   /* Assemble an array of points that comprise the slope correction
      template.  */

   _d_slope_corr_last = 400
   _d_total_pmp = number of pavement points
   _d_counter = 1
   _d_continue = 0

   while _d_counter <= _d_total_pmp
      {
      draw skip to p[_d_counter]
      _d_slope_corr_last = _d_slope_corr_last + 1
      mark x[_d_slope_corr_last] y[_d_slope_corr_last]
      _d_counter = _d_counter + 1
      }
      
   /* Go find the location of the existing ground */
   draw skip trace in off=0 for dx=300
   if intersect dgn = "existing edge of travel lane" then
     {
       draw skip trace out off=0 to "existing edge of travel lane"
       mark x100 y100
       draw skip trace out off=0 for dx=2*tolerance
       if intersect dgn = "existing edge of travel lane" then
         {
           draw skip trace out off=0 to "existing edge of travel lane"
           mark x101 y101
           _d_continue = 1
         }
       else
         {
           draw skip to xpgl ypgl
           draw text char=^2 Edge of Pavement's Not Found^ "~warning text symbology"
         }
     }
   else
     {
       draw skip to xpgl ypgl
       draw text char=^2 Edge of Pavement's Not Found^ "~warning text symbology"    
     }
   
   /* If you found two edges of pavement then continue */
   if _d_continue = 1 then
   {
   /* --------------------------------------------------------------------- */
   /* Loop over both the Slope Correction Template as well as the 
      Existing Ground Endpoints to determine the Critical Point. */

   _d_min_dist = 9999999.0
   _d_slope_corr_count = 401

   /* First: Loop over the Slope Correction Template to determine the Critical Point */
   while (_d_slope_corr_count <= _d_slope_corr_last)
      {
        draw skip to x[_d_slope_corr_count] y[_d_slope_corr_count]
        draw skip dx=0 dy=50
        draw skip dx = 0 dy=-1 to exist ground
        mark x502 y502

        if x502 >= x101 and x502 <= x100 then
          {
/*  
            _s_min_dist = " d1=" + cvt_d_s2(y[_d_slope_corr_count] - y502)
            draw text value=_s_min_dist "~warning text symbology"

*/  
            if (y[_d_slope_corr_count] - y502 < _d_min_dist) then
              {
                _d_min_dist = y[_d_slope_corr_count] - y502
                mark x599 y599
              }
          }
        _d_slope_corr_count = _d_slope_corr_count + 1
      }
   _d_slope_corr_count = _d_slope_corr_count - 1

   /* Second: Loop over the Existing Ground beneath the Slope Correction Template 
      to determine the Critical Point */
   draw skip to x[_d_slope_corr_count] y[_d_slope_corr_count]
   mark x500 y500
   while (x500 > x101)
      {
      draw skip dx=0 dy=50
      draw skip dx = 0 dy = -1 to exist ground
      draw skip trace "exground" out off=0 to endpoint
      mark x500 y500
      /* Loop over Slope Correction Template */
      _d_slope_corr_count = 401
      while (_d_slope_corr_count < _d_slope_corr_last) and x500 >= x101 and x500 <= x100
         {
         if (x500 > x[_d_slope_corr_count]) and
            (x500 < x[_d_slope_corr_count+1]) then
            {
            draw skip to x500 y500
            draw skip dx=0 dy=-50

            draw skip dx = 0 dy = 1 to intersect 
                x[_d_slope_corr_count] y[_d_slope_corr_count]
                x[_d_slope_corr_count+1] y[_d_slope_corr_count+1]

            if (el diff < _d_min_dist) then
               {
               _d_min_dist = el diff
/*  
            _s_min_dist = " d2=" + cvt_d_s2(_d_min_dist)
            draw text value=_s_min_dist "~warning text symbology"
*/  
               draw skip dx = 0 dy = 50
               draw skip dx = 0 dy = -1 to exist ground
               mark x599 y599               
               }
            }
         _d_slope_corr_count = _d_slope_corr_count + 1
         }
      }
   
   _d_eop_count = 100

   /* Third: Loop over the two edges of pavement to determine Critical Point */ 
   while (_d_eop_count <= 101)
      {
        draw skip to x[_d_eop_count] y[_d_eop_count]
        mark x500 y500
        /* Loop over Slope Correction Template */
        _d_slope_corr_count = 401
        while (_d_slope_corr_count < _d_slope_corr_last)
         {
         if (x500 > x[_d_slope_corr_count]) and
            (x500 < x[_d_slope_corr_count+1]) then
            {
            draw skip to x500 y500                  
            draw skip dx=0 dy=-50  

            draw skip dx = 0 dy = 1 to intersect           
                x[_d_slope_corr_count] y[_d_slope_corr_count]
                x[_d_slope_corr_count+1] y[_d_slope_corr_count+1]  

            if (el diff < _d_min_dist) then
               {
               _d_min_dist = el diff
/*  
            _s_min_dist = " d3=" + cvt_d_s2(_d_min_dist)
            draw text value=_s_min_dist "~warning text symbology"
*/  
               draw skip dx = 0 dy = 50
               draw skip dx = 0 dy = -1 to exist ground
               mark x599 y599               
               }
            }
         _d_slope_corr_count = _d_slope_corr_count + 1
         }
         _d_eop_count = _d_eop_count + 1
      }

       
       draw skip to x599 y599
       _s_min_dist = " Min. Distance @CP = " + cvt_d_s2(_d_min_dist)
	 set plot param "~XS notes line symbology"
	 draw dx=0 dy=-3
	 set plot param "~critical surface symbology"
       draw skip to x599 y599
       draw skip dx=-.25 dy=-1
       draw text value=_s_min_dist angle=-90 "~XS notes text symbology"

       _d_total_distance = abs("minimum overlay depth") - _d_min_dist
       draw skip to xpgl ypgl
       draw skip dx=0 dy=_d_total_distance
       mark x999 y999
       draw text char=^CL^ "~critical point CL text symbology"
       draw skip dx=0 dy=.5
       _d_elev = abs(y999)
       _s_elev = "Elev. @CL = " + cvt_d_s2(_d_elev)
       draw text value=_s_elev "~XS notes text symbology"

       /* DRAW THE NEW PROPOSED SLOPES WITH TIES */
       _d_count = 401
       while _d_count <= _d_slope_corr_last
         {
           draw skip to x[_d_count] y[_d_count]
           draw skip dx=0 dy=_d_total_distance
           mark x[_d_count] y[_d_count]
           _d_count = _d_count + 1
         }

       _d_count = 401
       draw skip to x[_d_count] y[_d_count]
	 set plot param "~critical surface symbology"
       draw skip dx=0 dy=50
       draw skip dx=0 dy=-1 to existing ground
       mark x499 y499               

       draw to x[_d_count] y[_d_count]
       draw text char=^EOP-L^ "~existing EOP text symbology" 
       draw skip to x[_d_count] y[_d_count]

       while _d_count < _d_slope_corr_last
         {
           draw to x[_d_count+1] y[_d_count+1]
           draw slope text between x[_d_count] y[_d_count]and x[_d_count+1] y[_d_count+1] 
             "~slope text symbology"  
           draw skip to x[_d_count+1] y[_d_count+1]
           _d_count = _d_count + 1 
         }
       draw skip dx=0 dy=50
       draw skip dx=0 dy=-1 to existing ground
       draw to x[_d_count] y[_d_count]
       draw text char=^EOP-R^ "~existing EOP text symbology"

       /* MARK ELEVATION DIFFERENCE (dE) at the Pavement Break */
       _d_count = 401
       while _d_count <= _d_slope_corr_last
         {
          draw skip to x[_d_count] y[_d_count]
	    _s_min_dist = " dE= " + cvt_d_s2(el diff)
          draw skip dx=0 dy=-1 to existing ground
          draw skip dx=0 dy=-1
          draw text value=_s_min_dist "~XS notes text symbology" 
          _d_count = _d_count + 1 
         }

/*   C/L    */
/*
	 _d_count = 999                                      
       	draw skip to x[_d_count] y[_d_count]
       	_s_min_dist = " dE=" + cvt_d_s2(el diff)
       	draw text value=_s_min_dist "~XS notes text symbology" 
*/

/*  edge of travel lane */
/*
   	 _d_top_count = 200                         

   	 while (_d_top_count <= 201)
	   {
     		draw skip to x[_d_top_count] y[_d_top_count]
       	draw skip dx=0 dy=_d_total_distance    
       	_s_min_dist = " dE=" + cvt_d_s2(el diff)
       	draw text value=_s_min_dist "~XS notes text symbology"
		_d_top_count = _d_top_count + 1
         }
*/

   } 
}

/* --------------------------------------------------------------------- */ 
 



      
      
