/*    Critical Point Calculation for Resufacing & Slope Correction.    */
/* ------------------------------------------------------------
      This program will 
		-  Locate Critical Points.
            -  Calculate C/L Elevation and 'minimum overlay depth'.
            -  Redraw Pavement Templates (shifting up and down). 
		-  Mark 'CL' on Pavement Templates for Profile Design. 

	Required:  
		-  x-section (dx) file with existing ground.	
		-  SE shapes tie to existing 
            -  Minimum overlay depth.		
			
	Change to level names						NPY  4/25/06	

	Include definitions: in std_vars.x:				NPY  4/25/06
		"~XS notes text symbology"
		"~critical point CL text symbology" 
		"~critical surface symbology"
		"~slope text symbology" 

---------------------------------------------------------------------------  */

define "minimum overlay depth" 0.3


define_dgn "exground" \
       dgn = ****.dgn \
       lvname=RD_XS_ExGround
        
if p2 then
   {
   /* --------------------------------------------------------------------- */
   /* Assemble an array of points that comprise the slope correction
      template.  */
   _d_slope_corr_last = 400
   _d_total_pmp = number of pavement points
   _d_counter = 1

   while _d_counter <= _d_total_pmp
      {
      draw skip to p[_d_counter]
      _d_slope_corr_last = _d_slope_corr_last + 1
      mark x[_d_slope_corr_last] y[_d_slope_corr_last]
      _d_counter = _d_counter + 1
      }
 
   /* --------------------------------------------------------------------- */
   /* Loop over both the Slope Correction Template as well as the 
      Existing Ground Endpoints to determine the Critical Point. */
   _d_min_dist = 9999999.0
   _d_slope_corr_count = 401

   /* First loop over the Slope Correction Template to determine the Critical Point */
   while (_d_slope_corr_count <= _d_slope_corr_last)
      {
      draw skip to x[_d_slope_corr_count] y[_d_slope_corr_count]
      draw skip dx=0 dy=50
      draw skip dx = 0 dy=-1 to exist ground
      mark x502 y502

         _s_min_dist = " dE=" + cvt_d_s2(y[_d_slope_corr_count] - y502)
         draw text value=_s_min_dist ang=-90 offset =0.5 "~XS notes text symbology" 

      if (y[_d_slope_corr_count] - y502 < _d_min_dist) then
         {
         _d_min_dist = y[_d_slope_corr_count] - y502
         mark x599 y599
         }
      _d_slope_corr_count = _d_slope_corr_count + 1
      }
   _d_slope_corr_count = _d_slope_corr_count - 1

   /* Loop over the Existing Ground beneath the Slope Correction Template 
      to determine the Critical Point */
   draw skip to x[_d_slope_corr_count] y[_d_slope_corr_count]
   mark x500 y500
   while (x500 > x401)
      {
      draw skip dx=0 dy=50
      draw skip dx = 0 dy = -1 to exist ground
      draw skip trace "exground" out off=0 to endpoint
      mark x500 y500
      /* Loop over Slope Correction Template */
      _d_slope_corr_count = 401
      while (_d_slope_corr_count < _d_slope_corr_last)
         {
         if (x500 > x[_d_slope_corr_count]) and
            (x500 < x[_d_slope_corr_count+1]) then
            {
            draw skip to x500 y500
            draw skip dx = 0 dy = 1 to intersect 
                x[_d_slope_corr_count] y[_d_slope_corr_count]
                x[_d_slope_corr_count+1] y[_d_slope_corr_count+1]
            if (el diff < _d_min_dist) then
               {
               _d_min_dist = el diff
               draw skip dx = 0 dy = 50
               draw skip dx = 0 dy = -1 to exist ground
               mark x599 y599               
               }
            }
         _d_slope_corr_count = _d_slope_corr_count + 1
         }
      }

   draw skip to x599 y599
   _s_min_dist = "Min. Distance @CP = " + cvt_d_s2(_d_min_dist)
   draw text value=_s_min_dist angle=90 offset =0.25 "~XS notes text symbology"

   _d_total_distance = abs("minimum overlay depth") - _d_min_dist
   draw skip to xpgl ypgl
   draw skip dx=0 dy=_d_total_distance
   mark x999 y999
   draw text char=^CL^ "~critical point CL text symbology" 
   draw skip dx=0 dy=.5
   _d_elev = abs(y999)
   _s_elev = "Elev. @CL = " + cvt_d_s2(_d_elev)
   draw text value=_s_elev "~XS notes text symbology"

   /* DRAW THE NEW PROPOSED SLOPES WITH TIES */
   _d_count = 401
   while _d_count <= _d_slope_corr_last
     {
       draw skip to x[_d_count] y[_d_count]
       draw skip dx=0 dy=_d_total_distance
       mark x[_d_count] y[_d_count]
       _d_count = _d_count + 1
     }

   _d_count = 401
   draw skip to x[_d_count] y[_d_count]
   set plot param "~critical surface symbology"
   draw skip dx=0 dy=50
   draw skip dx=0 dy=-1 to existing ground
   mark x499 y499               
   draw to x[_d_count] y[_d_count]
   while _d_count < _d_slope_corr_last
     {
       draw to x[_d_count+1] y[_d_count+1]
       draw slope text between x[_d_count] y[_d_count]and x[_d_count+1] y[_d_count+1] 
         "~slope text symbology"  
       draw skip to x[_d_count+1] y[_d_count+1]
       _d_count = _d_count + 1 
     }
   draw skip dx=0 dy=50
   draw skip dx=0 dy=-1 to existing ground
   draw to x[_d_count] y[_d_count]

   _d_count = 401 
   while _d_count <= _d_slope_corr_last
     {
       draw skip to x[_d_count] y[_d_count]
       _s_min_dist = " dE=" + cvt_d_s2(el diff)
       draw text value=_s_min_dist "~XS notes text symbology" ang=90  
       _d_count = _d_count + 1 
     }

   }

   /* --------------------------------------------------------------------- */
 



      
      
