/*  Draws overlay, widening, and milling by matching existing pavement  */

/*----------------------------------------------------------------------------------------    

Draw skip trace in off=0 for dx=300            	NPY  	9/28/01  
Widen pavement left & right			
Include Earth shoulders and tie slope L&R -

     side slope left
	   include std_vars.x                 
         include var_resurf_wid.x
         include match_pave_wid.x
         get shoulder_res_rt.x
         get shoulder_res_lf.x
         get rural_tie_res_lf.x
         get rural_tie_res_rt.x
	   get sc_typ80a(b)_pave_res_wid.xd 		NPY	11/03/03 

*** Sign convensions of slope and coordinate are based on side slope left  ***   

	draw skip trace "exground" out off=0 to endpoint   	! right
	draw skip trace "exground" in off=0 to endpoint		! left

	_d_slope_rt = (y350 - y351)/abs(x350 - x351)*100
	_d_slope_lf = (y360 - y361)/abs(x360 - x361)*100

	draw slope = _d_slope_rt for dx= -1 *"extent pavement width right" 
	draw slope = _d_slope_lf for dx= "extent pavement width left" 	NPY	11/03/03 

Change to level names							NPY  4/25/06	

----------------------------------------------------------------------------------------*/



/*****************************************************************
This section of the file marks and labels each edge of pavement
*****************************************************************/

if p1 then
{
_d_stop = 0
_d_eop_intersection = 0
_d_eop_intersection_counter = 1

mark x900 y900
draw skip trace in off=0 for dx=300
mark x901 y901

/*  mark  EXISTING EDGES OF PAVEMENT  X1 - X19 */

     if intersect dgn = "existing edge of travel lane" then
          {
          _d_eop_intersection = 1
          _d_eop_intersection_counter = 1
          while intersect dgn = "existing edge of travel lane"
               {
               draw skip dx = 1 dy = 0 to "existing edge of travel lane"
               draw skip dx = 0 dy = 50
               draw skip dx = 0 dy = -1 to exist ground
               mark x[_d_eop_intersection_counter] y[_d_eop_intersection_counter]
               _d_eop_intersection_counter = _d_eop_intersection_counter + 1
               draw skip dx = (2 * tolerance) dy = 0
               }
          }
     _d_eop_intersection_counter = _d_eop_intersection_counter - 1
          

/*********************************************************************************
Check for odd number of edges of pavement and issue error message
**********************************************************************************/

_d_temp = _d_eop_intersection_counter / 2
_d_temp_int = INT(_d_temp)

if _d_temp > _d_temp_int then
  {
  draw skip to xpgl ypgl
  draw text char=^Irregular Pavement Found^ "~warning text symbology"
  _d_stop = 1
  }

}

/***************************************************************************************
This while loop loops over each of the edge of pavement pairs and draws the existing
pavement and shoulder subbase
****************************************************************************************/

if _d_stop = 0  then

   {
   _d_admin_counter = 1
   _d_median = 0
   while (_d_admin_counter < _d_eop_intersection_counter)
      {
      _d_global_counter = _d_admin_counter
      
/***************************************************************************
This section draws the existing pavement subbase
***************************************************************************/

 if p1 then
   {
   _d_rt_eop = _d_global_counter

   /* Draw Pavement */
   set plot parameters "~pavement overlay symbology"
   draw skip to x[_d_rt_eop] y[_d_rt_eop]
   draw skip dx = 0 dy = abs("overlay thickness")
   mark x300 y300
   mark x500 y500

   draw trace out off = abs("overlay thickness") to x[_d_rt_eop+1]
   mark x301 y301
   mark x501 y501

/*   draw dx = 0 dy = -1 to existing ground
*/
 	set plot parameters "~pavement symbology"

	draw skip to x300 y300
	draw skip dx = 0 dy = 50
	draw skip dx = 0 dy = -1 to exist ground
	mark x350 y350
	draw skip trace "exground" out off=0 to endpoint
	mark x351 y351
	if abs(x351-x350) < 1.5  then
		{         /*  Read the next segment for EOP error */
		mark x350 y350
		draw skip trace "exground" out off=0 to endpoint
		mark x351 y351
		}

	draw skip to x301 y301
	draw skip dx = 0 dy = 50
	draw skip dx = 0 dy = -1 to exist ground
	mark x360 y360
	draw skip trace "exground" in off=0 to endpoint
	mark x361 y361
	if abs(x361-x360) < 1.5  then
		{
		mark x360 y360
		draw skip trace "exground" in off=0 to endpoint
		mark x361 y361
		}

	draw skip to x300 y300
	draw skip dx = 20 dy = -10

	_d_slope_rt = (y350 - y351)/abs(x350 - x351)*100
	_d_slope_lf = (y360 - y361)/abs(x360 - x361)*100

/*----------------------- debug ---------------------------------------
 	_s_text = "slope rt = " + cvt_d_s2(_d_slope_rt) + "***"
	draw text value= _s_text co=3 
	draw skip dx = 0 dy = -5
 	_s_text = "slope lf = " + cvt_d_s2(_d_slope_lf) + "***"
	draw text value= _s_text co=3 
---------------------------------------------------------------------*/
 
   /* Draw Milling */
   set plot parameters "~milling symbology"
   draw skip to x[_d_rt_eop] y[_d_rt_eop]
   draw dx=0 dy=-abs("milling thickness")
   mark x302 y302
   draw trace out off=-abs("milling thickness") to x[_d_rt_eop+1]
   mark x303 y303
   draw dx=0 dy=1 to existing ground

   /* TIE TO GROUND */
   set plot parameters "~paved shoulder symbology" 
   draw skip to x300 y300

	draw slope = _d_slope_rt for dx= -1 *"extent pavement width right" 
	mark x370 y370
   	draw skip to x300 y300
	draw skip dx=0 dy=-abs("pavement thickness")
      set plot parameters "~pavement symbology" 
	draw slope = _d_slope_rt for dx= -1 *"extent pavement width right" 

   	draw skip to x370 y370
    	_d_slope = _d_slope_rt 
    	include shoulder_res_rt.x
     	include rural_tie_res_rt.x

   draw skip to x301 y301

   	set plot parameters "~paved shoulder symbology" 
	draw slope = _d_slope_lf for dx= "extent pavement width left" 
	mark x371 y371

   	draw skip to x301 y301
	draw skip dx=0 dy=-abs("pavement thickness")

   	set plot parameters "~pavement symbology" 
	draw slope = _d_slope_lf for dx= "extent pavement width left" 

	draw skip to x371 y371
    	_d_slope = _d_slope_lf 

    	include shoulder_res_lf.x
     	include rural_tie_res_lf.x

   }  
         



/***************************************************************
Reset the counter and go to the next pair of eop's
***************************************************************/
         
      _d_admin_counter = _d_admin_counter + 2
     }
   }
