/* Draws tie slopes for rural projects */
/*-----------------------------------------------------------------------------------
	NPDES : Erotion Control Limimit

      x1, y1 : top of the slope  
      x2, y2 : btm of the slope  
      x13,y13 : Erotion control limit (R/W or permit) 
	For More info. see Instruction Bulletin # 96-2  

	Add 3pc to draw NPDES lines on plan view 			
	NPDES report							3/13/01   	NPY   
	Add Special Ditch symbology					5/5/01	NPY
      Adjust: 
      if "ditch distance" < 6 then {_d_fs = 4:1 }    		8/14/01     NPY
      draw skip trace out off=0 for dx=300           		9/28/01     NPY
	Overwrite slope text symbology (co=4)				2/15/02	NPY
	Modify ECL (See IB # 2002-7)					2/21/03	NPY
	Change to level names							4/25/06	NPY	

	Add option to draw guardrail post embedment   		3/8/2017   NPY
	 
-------------------------------------------------------------------------------------*/    

/*********************** define guardrail subroutine ********************************/
subroutine guardrail
 { 
   mark x100 y100
   set plot parameters "~greenside symbology"
   _d_sh_slope = "shoulder slope"
   if pavement slope >= 0 then
     {
       draw slope = _d_sh_slope:-1 for dx = 3.75
     }
   else
     {
       draw slope = -pavement slope for dx=3.75
     }
   mark x200 y200
   draw skip to x100 y100
   draw skip dx = .167 dy = 1.490                  /* dx=2" dy = 31"  */
   mark x300 y300

   /* Draw posts   */
   set plot parameters "~guardrail symbology"
   draw skip to x300 y300
   draw dx = 0.917 dy =0                             /* dx = 11"  */                      
   draw skip to x300 y300
   draw dx = 0 dy = 1 for dy = 1.167                   /* 14" */
   mark x400 y400
   draw dx = 1 dy = 0 for dx = 0.917                   /* 11" */ 
   mark x500 y500
   draw dx = 0 dy = -1 to intersection x100 y100 x200 y200
   mark x511 y511
   draw skip to x500 y500
   draw dx = 1 dy = 0 for dx = 0.666                   /* 8" */ 
   draw dx = 0 dy = -1 to intersection x100 y100 x200 y200

   /*  Draw guardrail post embedment */
   define "~guardrail post embedment symbology" lvname=RD_XS_GR co=14 wt=4 lc=2
   define "draw guardrail post embedment" 1               
   define "guardrail post embedment depth in inch" 41               

   if "draw guardrail post embedment" = 1 then 
	{               
   	set plot parameters "~guardrail post embedment symbology" 
   	_d_grp_depth = "guardrail post embedment depth in inch" / 12     
   	draw dx = 0 dy = - _d_grp_depth						/* Default = 41" */
   	draw skip dx = -0.666 dy = 0                    		/* 8" */ 
   	draw to x511 y511
	}	
   	set plot parameters "~guardrail symbology"

   /* Draw rails  */
   draw skip to x300 y300
   draw skip dx=0 dy = 1 for dy=0.073                   /* 7/8"  */
   draw dx = -0.167 dy = 0.20
   draw dx=0 dy= 0.05
   draw dx = 0.167 dy = 0.20
 
   draw skip to x400 y400
   draw skip dx=0 dy = -1 for dy=0.073                   /* 7/8" */
   draw dx = -0.167 dy = -0.20
   draw dx=0 dy= -0.05
   draw dx = 0.167 dy = -0.20
   draw skip to x200 y200

 }
end subroutine 
/*************************************************************************/

if p1 then
  {
    set plot parameters "~ditch slope symbology"  
	_d_spec_ditch = 0

    if "ditch distance" >= 6 then
      {
        _d_fs = "std front slope"
      }
    else if "ditch distance" < 6 then
      {
        _d_fs = 4:1
      }
    _d_bs = "std back slope"
    mark x1 y1
    draw skip trace out off=0 for dx=300
    mark x600 y600
    draw skip dx=1 dy=0
    mark x601 y601
    draw skip to x1 y1

    /* CHECK FOR SPECIAL PROFILE ON LEFT SIDE */
    if px1 < px2 and station within profile = "ditch profile lt" then
      {
         draw slope = -abs(_d_fs) to profile elev = "ditch profile lt"
         mark x2 y2
	   _d_spec_ditch = 1
	   draw skip dx=0 dy=-5	
         draw text char=^Special ditch^ "~warning text symbology" ang=0 just=ct 
	   draw skip to x2 y2

		/*   Pause drawing NPDES lines  */ 
  		if px1 < px2 then          
			{ _d_draw_left = 0 }
  		else
			{ _d_draw_right= 0 }

         if elev diff < 0 then
           {
             draw skip dx=abs("ditch bottom width") dy=0
             mark x3 y3
             draw skip to x2 y2
             if elev diff at x3 y3 < 0 then
               {
                 draw to x3 y3
                 draw slope = abs(_d_bs) to existing ground
                 mark x4 y4
                 if abs(x3 - x4) < tolerance then
                   {
                     draw slope = abs(_d_bs) to intersection x600 y600 x601 y601
                     mark x3 y3
                     set plot parameters "~existing ground symbology"
                     draw to x600 y600
                   }
               }
             else if elev diff at x3 y3 >= 0 then
               {
                 draw dx=1 dy=0 to existing ground
                 mark x3 y3
                 mark x4 y4
               }
           }
         else
           {
             draw text char=^Warning: Ditch Above Ground^ "~warning text symbology"
           }
      }

    /* CHECK FOR SPECIAL PROFILE ON RIGHT SIDE */
    else if px1 > px2 and station within profile = "ditch profile rt" then
      {
         draw slope = -abs(_d_fs) to profile elev = "ditch profile rt"
         mark x2 y2
	   _d_spec_ditch = 1
	   draw skip dx=0 dy=-5	
         draw text char=^Special ditch^ "~warning text symbology" ang=0 just=ct 
	   draw skip to x2 y2

		/*   Pause drawing NPDES lines  */ 
  		if px1 < px2 then          
			{ _d_draw_left = 0 }
  		else
			{ _d_draw_right= 0 }

         if elev diff < 0 then
           {
             draw skip dx=abs("ditch bottom width") dy=0
             mark x3 y3
             draw skip to x2 y2
             if elev diff at x3 y3 < 0 then
               {
                 draw to x3 y3
                 draw slope = abs(_d_bs) to existing ground
                 mark x4 y4
                 if abs(x3 - x4) < tolerance then
                   {
                     draw slope = abs(_d_bs) to intersection x600 y600 x601 y601
                     mark x3 y3
                     set plot parameters "~existing ground symbology"
                     draw to x600 y600
                   }
               }
             else if elev diff at x3 y3 >= 0 then
               {
                 draw dx=1 dy=0 to existing ground
                 mark x3 y3
                 mark x4 y4
               }
           }
         else
           {
             draw text char=^Warning: Ditch Above Ground^ "~warning text symbology"
           }
      }

    /* CHECK FOR NORMAL CUT OR FILL */
    else
      {
        draw skip slope = -abs(_d_fs) for dx="ditch distance"
        mark x2 y2
        draw skip to x1 y1

        /* IF YOU ARE IN CUT */
        if elevation difference at x2 y2 < 0 then
          {
            draw to x2 y2
            draw skip dx=abs("ditch bottom width") dy=0
            mark x3 y3
            draw skip to x2 y2
		/*   Pause drawing NPDES lines  */ 
  		if px1 < px2 then          
			{ _d_draw_left = 0 }
  		else
			{ _d_draw_right= 0 }

            if elev diff at x3 y3 < 0 then
              {
                draw to x3 y3
                draw slope = abs(_d_bs) to existing ground
                mark x4 y4
                if abs(x3 - x4) < tolerance then
                  {
                    draw slope = abs(_d_bs) to intersection x600 y600 x601 y601
                    mark x4 y4
                    set plot parameters "~existing ground symbology"
                    draw to x600 y600
                  }
              }
            else if elev diff at x3 y3 >= 0 then
              {
                draw dx=1 dy=0 to existing ground
                mark x3 y3
                mark x4 y4
              }
          }

        /* ELSE IF YOU ARE IN FILL */
        else if elevation diff at x2 y2 > 0 then
          {
            draw skip slope = 6:-1 to existing ground
        	_d_fill_slope = 6:1 

            mark x2 y2
            draw skip to x1 y1
            if abs(y1 - y2) <= 5 and abs(x2 - x1) > tolerance then
              {
                draw to x2 y2
                mark x3 y3
                mark x4 y4
              }
            else 
              {
                draw skip slope = 4:-1 to existing ground
        	    _d_fill_slope = 4:1 
                mark x2 y2
                draw skip to x1 y1
                if abs(y1 - y2) > 5 and abs(y1 - y2) <= 10 and abs(x1 - x2) > tolerance then
                  {
                    draw to x2 y2
                    mark x3 y3
                    mark x4 y4
                  }
                else
                  {
                    draw skip slope = 2:-1 to existing ground
			  _d_fill_slope = 2:1 
                    mark x2 y2
                    draw skip to x1 y1
                    if abs(x1 - x2) > tolerance then
                      {
                        call subroutine guardrail
                        mark x1 y1                                              /* Add 3.75' */
                        set plot parameters "~ditch slope symbology"  
                        draw slope = 2:-1 to existing ground                    /*   */
                        mark x2 y2
                        mark x3 y3
                        mark x4 y4
                      }
                    /* IF EVERYTHING FAILS, YOU ARE HERE ... EXTEND GROUND */
                    else if abs(x1 - x2) < tolerance then
                      {
                        draw skip slope = 6:-1 to intersection x600 y600 x601 y601
        			 _d_fill_slope = 6:1 
                        mark x2 y2
                        draw skip to x1 y1
                        if abs(y1 - y2) <= 5 then
                          {
                            draw to x2 y2
                            mark x3 y3
                            mark x4 y4
                            set plot parameters "~existing ground symbology"
                            draw to x600 y600
                          }
                        else
                          {
                            draw skip slope = 4:-1 to intersection x600 y600 x601 y601
         			     _d_fill_slope = 4:1   
		                 mark x2 y2
         			     draw skip to x1 y1
                            if abs(y1 - y2) > 5 and abs(y1 - y2) <= 10 then
                              {
                                draw to x2 y2
                                mark x3 y3
                                mark x4 y4
                                set plot parameters "~existing ground symbology"
                                draw to x600 y600
                              }
                            else
                              {
                                call subroutine guardrail
                                mark x1 y1
                                set plot parameters "~ditch slope symbology"  
                                draw slope = 2:-1 to intersection x600 y600 x601 y601
					  _d_fill_slope = 2:1 
                                mark x2 y2
                                mark x3 y3
                                mark x4 y4
                                set plot parameters "~existing ground symbology"
                                draw to x600 y600
                              }
                          }
                      }
                  } 		/* Fill <> 4:1 */
              }            	/* Fill <> 6:1 */

	  	_d_fill_height = abs(y1-y2)         	 /* fill height   */
	  	if "draw npdes lines on xs" = 1 then       /* draw ecl (NPDES)  */
		{ call draw_npdes2 }

           }               	/* Fill ENDIF  */
       }

     /* LABEL SLOPES & Elevation*/
     if p1 then
       {
     	   _d_elev = abs(y2)
     	   draw skip to x2 y2
         draw skip dx=0.0 dy=2                             
         _s_elev = cvt_d_s2(_d_elev)             
	   if _d_spec_ditch = 0 then
	   	{
         	draw text value=_s_elev "~elevation text symbology"
		}
	   else 
	   	{
         	draw text value=_s_elev "~elevation text symbology" co=3
		}	
         draw slope text between x1 y1 and x2 y2 "~slope text symbology" co=4
         if abs(x3 - x4) > tolerance then
           {
             draw slope text between x3 y3 and x4 y4 "~slope text symbology" co=4
           }
       }
  
  }
/*----------------------------------------------------------------------*/
SUBROUTINE draw_npdes2
	{

		if _d_fill_height < 6 then
			{
			_d_min_offset = 3
			}
		else if _d_fill_height >= 6 and _d_fill_height <= 10 then
			{
			if _d_fill_slope = 50 then
			 	{
			 	_d_min_offset = 13
				}
			else  
			 	{
				_d_min_offset = 4
				}
			}
		else						/* Fill Height > 10  */
			{
			if _d_fill_slope = 50 then   /* Fill Slope = 50% = (2:1)  */ 
			 	{
			 	_d_min_offset = 13
				}
			else  
			 	{
				_d_min_offset = 5
				}
			}

		draw skip to x2 y2
		draw skip dx=_d_min_offset dy =0
		mark x13 y13
 
/*---------------------------------------------------------*/
/*	  Draw Erotion Control Limit on XS                   */
/*---------------------------------------------------------*/		
   		set plot parameters "~npdes line symbology" 
		draw dx=0 dy=3        
		draw text char= ^ NPDES^ "~warning text symbology" angle=90
		draw skip to x13 y13
		draw skip dx=0 dy=-2
     		_s_text = "Fill Height = " + cvt_d_s2(_d_fill_height) + "' "
		draw text value= _s_text "~warning text symbology" angle=0
		draw skip to x13 y13

		draw skip dx=0 dy=-3
     		_s_text = "Fill Slope = " + cvt_d_s2(100/_d_fill_slope)+ ": 1" 
		draw text value= _s_text "~warning text symbology" angle=0
		draw skip to x13 y13

		draw skip dx=0 dy=-4
     		_s_text = "Min. Offset = " + cvt_d_s2(_d_min_offset ) + "' "
		draw text value= _s_text "~warning text symbology" angle=0

/* ************** Draw NPDES Lines on Plan view *************** */

		draw skip to x13 y13
	  	if "draw npdes lines on plan view" = 1 then       /* geopak 2000 only  */
			{
			mark _mp_xs_cur
        		if (not _mp_xs_prev) then
				{
				prompt ^Select a plan view file for NPDES lines.(e.g. *pp.dgn) ^ 
                               variable= _s_plan_file mode=file select filter=*.dgn
	     			if (CANCEL) then {EXIT}
				}
			draw skip to _mp_xs_cur
			mark _mp_xs_prev
			call SUB draw_ecl2 (PLAN VIEW = _s_plan_file)
			}

	}
end sub

/* ************** PLAN VIEW - Draw NPDES Lines on Plan view *************** */
SUBROUTINE draw_ecl2
{
   	/* handles left side */
   	if px1 < px2 then
      	{
		mark _mp_lt_cur
         	/* if _mp_lt_prev doesn't exist you're on the first xs    */
        	/* or, if _d_draw_left= 1 ==> prev. lt xs is fill.       */

        	if (_mp_lt_prev) and (_d_draw_left =1) then
        		{  
           		set plot parameters "~plan view ecl symbology"
          		draw skip to _mp_lt_prev
           		draw gg=^leftlimits^ to _mp_lt_cur
			}
           	mark _mp_lt_prev
		_d_draw_left = 1
		} 
  	/* handles right side */
   	else if px1 > px2 then
   		{
      	mark _mp_rt_cur

         	/* if _mp_rt_prev doesn't exist you're on the first xs */
        	/* or, if _d_draw_right= 1 ==> prev. rt xs is fill     */

        	if (_mp_rt_prev) and (_d_draw_right =1) then
      		{
            	set plot parameters "~plan view ecl symbology"
            	draw skip to _mp_rt_prev
            	draw gg=^rightlimits^ to _mp_rt_cur
          		}
           	mark _mp_rt_prev
		_d_draw_right= 1
        	}
}
end subroutine
    
    
    
  
