/* Draws tie slopes for rural projects */
/*----------------------------------------------------------------------------
	Change 'draw skip trace out for dx=200' 			1/24/01  	NPY

	Overwrite slope text symbology (co=4)				2/15/02	NPY

	Change to Level Name							3/12/09	NPY
	Add option to draw guardrail post embedment   		3/8/2017   NPY

-----------------------------------------------------------------------------*/


/*********************** define guardrail subroutine ********************************/
subroutine guardrail
 { 
   mark x100 y100
   set plot parameters "~greenside symbology"
   _d_sh_slope = "shoulder slope"
   if pavement slope >= 0 then
     {
       draw slope = _d_sh_slope:-1 for dx = 3.75
     }
   else
     {
       draw slope = -pavement slope for dx=3.75
     }
   mark x200 y200
   draw skip to x100 y100
   draw skip dx = .167 dy = 1.490                  /* dx=2" dy = 31"  */
   mark x300 y300

   /* Draw posts   */
   set plot parameters "~guardrail symbology"
   draw skip to x300 y300
   draw dx = 0.917 dy =0                             /* dx = 11"  */                      
   draw skip to x300 y300
   draw dx = 0 dy = 1 for dy = 1.167                   /* 14" */
   mark x400 y400
   draw dx = 1 dy = 0 for dx = 0.917                   /* 11" */ 
   mark x500 y500
   draw dx = 0 dy = -1 to intersection x100 y100 x200 y200
   draw skip to x500 y500
   draw dx = 1 dy = 0 for dx = 0.666                   /* 8" */ 
   draw dx = 0 dy = -1 to intersection x100 y100 x200 y200

   /*  Draw guardrail post embedment */
   define "~guardrail post embedment symbology" lvname=RD_XS_GR co=14 wt=4 lc=2
   define "draw guardrail post embedment" 1               
   define "guardrail post embedment depth in inch" 41               

   if "draw guardrail post embedment" = 1 then 
	{               
   	set plot parameters "~guardrail post embedment symbology" 
   	_d_grp_depth = "guardrail post embedment depth in inch" / 12     
   	draw dx = 0 dy = - _d_grp_depth						/* Default = 41" */
   	draw skip dx = -0.666 dy = 0                    		/* 8" */ 
   	draw to x511 y511
	}	
   	set plot parameters "~guardrail symbology"

   /* Draw rails  */
   draw skip to x300 y300
   draw skip dx=0 dy = 1 for dy=0.073                   /* 7/8"  */
   draw dx = -0.167 dy = 0.20
   draw dx=0 dy= 0.05
   draw dx = 0.167 dy = 0.20
 
   draw skip to x400 y400
   draw skip dx=0 dy = -1 for dy=0.073                   /* 7/8" */
   draw dx = -0.167 dy = -0.20
   draw dx=0 dy= -0.05
   draw dx = 0.167 dy = -0.20
   draw skip to x200 y200

 }
end subroutine 
/*************************************************************************/

if p1 then
  {
    set plot parameters "~ditch slope symbology"  
    if "ditch distance" >= 5 then
      {
        _d_fs = "std front slope"
      }
    else if "ditch distance" < 5 then
      {
        _d_fs = 4:1
      }
    _d_bs = "std back slope"
    mark x1 y1
    draw skip trace out off=0 for dx=200
    mark x600 y600
    draw skip dx=1 dy=0
    mark x601 y601
    draw skip to x1 y1

    /* CHECK FOR SPECIAL PROFILE ON LEFT SIDE */
    if px1 < px2 and station within profile = "ditch profile lt" then
      {
         draw slope = -abs(_d_fs) to profile elev = "ditch profile lt"
         mark x2 y2
         if elev diff < 0 then
           {
             draw skip dx=abs("ditch bottom width") dy=0
             mark x3 y3
             draw skip to x2 y2
             if elev diff at x3 y3 < 0 then
               {
                 draw to x3 y3
                 draw slope = abs(_d_bs) to existing ground
                 mark x4 y4
                 if abs(x3 - x4) < tolerance then
                   {
                     draw slope = abs(_d_bs) to intersection x600 y600 x601 y601
                     mark x3 y3
                     set plot parameters "~existing ground symbology"
                     draw to x600 y600
                   }
               }
             else if elev diff at x3 y3 >= 0 then
               {
                 draw dx=1 dy=0 to existing ground
                 mark x3 y3
                 mark x4 y4
               }
           }
         else
           {
             draw text char=^Warning: Ditch Above Ground^ "~warning text symbology"
           }
      }

    /* CHECK FOR SPECIAL PROFILE ON RIGHT SIDE */
    else if px1 > px2 and station within profile = "ditch profile rt" then
      {
         draw slope = -abs(_d_fs) to profile elev = "ditch profile rt"
         mark x2 y2
         if elev diff < 0 then
           {
             draw skip dx=abs("ditch bottom width") dy=0
             mark x3 y3
             draw skip to x2 y2
             if elev diff at x3 y3 < 0 then
               {
                 draw to x3 y3
                 draw slope = abs(_d_bs) to existing ground
                 mark x4 y4
                 if abs(x3 - x4) < tolerance then
                   {
                     draw slope = abs(_d_bs) to intersection x600 y600 x601 y601
                     mark x3 y3
                     set plot parameters "~existing ground symbology"
                     draw to x600 y600
                   }
               }
             else if elev diff at x3 y3 >= 0 then
               {
                 draw dx=1 dy=0 to existing ground
                 mark x3 y3
                 mark x4 y4
               }
           }
      }

    /* CHECK FOR NORMAL CUT OR FILL */
    else
      {
        draw skip slope = -abs(_d_fs) for dx="ditch distance"
        mark x2 y2
        draw skip to x1 y1

        /* IF YOU ARE IN CUT */
        if elevation difference at x2 y2 < 0 then
          {
            draw to x2 y2
            draw skip dx=abs("ditch bottom width") dy=0
            mark x3 y3
            draw skip to x2 y2
            if elev diff at x3 y3 < 0 then
              {
                draw to x3 y3
                draw slope = abs(_d_bs) to existing ground
                mark x4 y4
                if abs(x3 - x4) < tolerance then
                  {
                    draw slope = abs(_d_bs) to intersection x600 y600 x601 y601
                    mark x4 y4
                    set plot parameters "~existing ground symbology"
                    draw to x600 y600
                  }
              }
            else if elev diff at x3 y3 >= 0 then
              {
                draw dx=1 dy=0 to existing ground
                mark x3 y3
                mark x4 y4
              }
          }

        /* ELSE IF YOU ARE IN FILL */
        else if elevation diff at x2 y2 > 0 then
          {
            draw skip slope = 6:-1 to existing ground
            mark x2 y2
            draw skip to x1 y1
            if abs(y1 - y2) <= 5 and abs(x2 - x1) > tolerance then
              {
                draw to x2 y2
                mark x3 y3
                mark x4 y4
              }
            else 
              {
                draw skip slope = 4:-1 to existing ground
                mark x2 y2
                draw skip to x1 y1
                if abs(y1 - y2) > 5 and abs(y1 - y2) <= 10 and abs(x1 - x2) > tolerance then
                  {
                    draw to x2 y2
                    mark x3 y3
                    mark x4 y4
                  }
                else
                  {
                    draw skip slope = 2:-1 to existing ground
                    mark x2 y2
                    draw skip to x1 y1
                    if abs(x1 - x2) > tolerance then
                      {
                        call subroutine guardrail
                        mark x1 y1                                              /* Add 3.75' */
                        set plot parameters "~ditch slope symbology"  
                        draw slope = 2:-1 to existing ground                    /*   */
                        mark x2 y2
                        mark x3 y3
                        mark x4 y4
                      }
                    /* IF EVERYTHING FAILS, YOU ARE HERE ... EXTEND GROUND */
                    else if abs(x1 - x2) < tolerance then
                      {
                        draw skip slope = 6:-1 to intersection x600 y600 x601 y601
                        mark x2 y2
                        draw skip to x1 y1
                        if abs(y1 - y2) <= 5 then
                          {
                            draw to x2 y2
                            mark x3 y3
                            mark x4 y4
                            set plot parameters "~existing ground symbology"
                            draw to x600 y600
                          }
                        else
                          {
                            draw skip slope = 4:-1 to intersection x600 y600 x601 y601
                            mark x2 y2
                            draw skip to x1 y1
                            if abs(y1 - y2) > 5 and abs(y1 - y2) <= 10 then
                              {
                                draw to x2 y2
                                mark x3 y3
                                mark x4 y4
                                set plot parameters "~existing ground symbology"
                                draw to x600 y600
                              }
                            else
                              {
                                call subroutine guardrail
                                mark x1 y1
                                set plot parameters "~ditch slope symbology"  
                                draw slope = 2:-1 to intersection x600 y600 x601 y601
                                mark x2 y2
                                mark x3 y3
                                mark x4 y4
                                set plot parameters "~existing ground symbology"
                                draw to x600 y600
                              }
                          }
                      }
                  }
              }
           }
       }

     /* LABEL SLOPES & Elevation*/
     if p1 then
       {
     	   _d_elev = abs(y2)
     	   draw skip to x2 y2
         draw skip dx=0.0 dy=2                             
         _s_elev = cvt_d_s2(_d_elev)             
         draw text value=_s_elev "~elevation text symbology"

         draw slope text between x1 y1 and x2 y2 "~slope text symbology" co=4
         if abs(x3 - x4) > tolerance then
           {
             draw slope text between x3 y3 and x4 y4 "~slope text symbology" co=4  
           }
       }
  
  }
    
    
    
  
