/* Draws tie slopes for urban projects */

/*-----------------------------------------------------------------------------------
      x1, y1 : top of the slope  
      x2, y2 : btm of the slope  
      x3, y3 : Erotion control limit (R/W or permit) 
	For More info. see Instruction Bulletin # 96-2  

	Add 3pc to draw NPDES lines on plan view 			
	NPDES report						1/1/01   	NPY   
	Change 'draw skip trace out for dx=200' 		1/24/01  	NPY    
	Modify ECL (See IB # 2002-7)				2/21/03	NPY

	Change to level names					4/25/06	NPY	

-------------------------------------------------------------------------------------*/    
if not intersect dgn = "side street in dgn" then  
  {
   	set plot parameters "~tie slope symbology"  
   	mark x1 y1
    	/* GET POINTS READY FOR GROUND LINE EXTENSION */  
    	draw skip trace out off=0 for dx=200  
    	mark x600 y600  
    	draw skip dx=1 dy=0 
    	mark x601 y601  
    	draw skip to x1 y1    

    /* IF YOU ARE IN FILL */
    if elevation difference > 0 then  
      {  
        _d_slope = "urban tie slope"
	  _d_fill_slope = _d_slope
        draw slope = -abs(_d_slope) to existing ground
        mark x2 y2
	  _d_fill_height = abs(y1-y2)         /* fill height   */
        if abs(x2 - x1) < tolerance then
          	{
            draw slope = -abs(_d_slope) to intersection x600 y600 x601 y601
            mark x2 y2
            set plot parameters "~existing ground symbology"
            draw to x600 y600
          	}
	  if "draw npdes lines on xs" = 1 then       /* draw erosion control limit (NPDES)  */
		{ call draw_npdes }
      }
    /* ELSE IF YOU ARE IN CUT */
    else
      {
	  if px1 < px2 then          
		{ _d_draw_left = 0 }
	  else
		{ _d_draw_right= 0 }

        _d_slope = "urban tie slope"
        draw slope = abs(_d_slope) to existing ground
        mark x2 y2
        if abs(x2 - x1) < tolerance then
          {
            draw slope = abs(_d_slope) to intersection x600 y600 x601 y601
            mark x2 y2
            set plot parameters "~existing ground symbology"
            draw to x600 y600
          }
      }
  }
  else
  {
  if px1 < px2 then          
	{ _d_draw_left = 0 }
  else
	{ _d_draw_right= 0 }
  }


SUBROUTINE draw_npdes
	{

		if _d_fill_height < 6 then
			{
			_d_min_offset = 3
			}
		else if _d_fill_height >= 6 and _d_fill_height <= 10 then
			{
			if _d_fill_slope = 50 then
			 	{
			 	_d_min_offset = 13
				}
			else  
			 	{
				_d_min_offset = 4
				}
			}
		else						/* Fill Height > 10  */
			{
			if _d_fill_slope = 50 then   /* Fill Slope = 50% = (2:1)  */ 
			 	{
			 	_d_min_offset = 13
				}
			else  
			 	{
				_d_min_offset = 5
				}
			}

		draw skip to x2 y2
		draw skip dx=_d_min_offset dy =0
		mark x3 y3
 
/*---------------------------------------------------------*/
/*	  Draw Erotion Control Limit on XS                   */
/*---------------------------------------------------------*/		
   		set plot parameters "~npdes line symbology" 
		draw dx=0 dy=3        
		draw text char= ^ NPDES^ "~warning text symbology" angle=90
		draw skip to x3 y3
		draw skip dx=0 dy=-2
     		_s_text = "Fill Height = " + cvt_d_s2(_d_fill_height) + "' "
		draw text value= _s_text "~warning text symbology" angle=0
		draw skip to x3 y3

		draw skip dx=0 dy=-3
     		_s_text = "Fill Slope = " + cvt_d_s2(100/_d_fill_slope)+ ": 1" 
		draw text value= _s_text "~warning text symbology" angle=0
		draw skip to x3 y3

		draw skip dx=0 dy=-4
     		_s_text = "Min. Offset = " + cvt_d_s2(_d_min_offset ) + "' "
		draw text value= _s_text "~warning text symbology" angle=0

/* ************** Draw NPDES Lines on Plan view *************** */

		draw skip to x3 y3
	  	if "draw npdes lines on plan view" = 1 then       /* geopak 2000 only  */
			{
			mark _mp_xs_cur
        		if (not _mp_xs_prev) then
				{
				prompt ^Select a plan view file for NPDES lines.(e.g. *pp.dgn) ^ 
                               variable= _s_plan_file mode=file select filter=*.dgn
	     			if (CANCEL) then {EXIT}
				}
			draw skip to _mp_xs_cur
			mark _mp_xs_prev
			call SUB draw_ecl (PLAN VIEW = _s_plan_file)
			}

	}
end sub

/* ************** PLAN VIEW - Draw NPDES Lines on Plan view *************** */
SUBROUTINE draw_ecl
{
	/* set symbologies */
   	/* handles left side */
   	if px1 < px2 then
      	{
		mark _mp_lt_cur
         	/* if _mp_lt_prev doesn't exist you're on the first xs    */
        	/* or, if _d_draw_left= 1 ==> prev. lt xs is fill.       */

        	if (_mp_lt_prev) and (_d_draw_left =1) then
        		{  
           		set plot parameters "~plan view ecl symbology"
          		draw skip to _mp_lt_prev
           		draw gg=^leftlimits^ to _mp_lt_cur
			}
           	mark _mp_lt_prev
		_d_draw_left = 1
		} 
  	/* handles right side */
   	else if px1 > px2 then
   		{
      	mark _mp_rt_cur

         	/* if _mp_rt_prev doesn't exist you're on the first xs */
        	/* or, if _d_draw_right= 1 ==> prev. rt xs is fill     */

        	if (_mp_rt_prev) and (_d_draw_right =1) then
      		{
            	set plot parameters "~plan view ecl symbology"
            	draw skip to _mp_rt_prev
            	draw gg=^rightlimits^ to _mp_rt_cur
          		}
           	mark _mp_rt_prev
		_d_draw_right= 1
        	}
}
end subroutine


